Rename objc_lifetime -> objc_ownership, and modify diagnostics to talk about 'ownership', not 'lifetime'.

rdar://9477613.

git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@133779 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/AST/TypePrinter.cpp b/lib/AST/TypePrinter.cpp
index ccb4560..b89d2aa 100644
--- a/lib/AST/TypePrinter.cpp
+++ b/lib/AST/TypePrinter.cpp
@@ -845,9 +845,9 @@
 
 void TypePrinter::printAttributed(const AttributedType *T,
                                   std::string &S) {
   // Prefer the macro forms of the GC and lifetime qualifiers.
   if (T->getAttrKind() == AttributedType::attr_objc_gc ||
-      T->getAttrKind() == AttributedType::attr_objc_lifetime)
+      T->getAttrKind() == AttributedType::attr_objc_ownership)
     return print(T->getEquivalentType(), S);
 
   print(T->getModifiedType(), S);
@@ -916,10 +916,10 @@
     break;
   }
 
-  case AttributedType::attr_objc_lifetime:
-    S += "objc_lifetime(";
+  case AttributedType::attr_objc_ownership:
+    S += "objc_ownership(";
     switch (T->getEquivalentType().getObjCLifetime()) {
-    case Qualifiers::OCL_None: llvm_unreachable("no lifetime!"); break;
+    case Qualifiers::OCL_None: llvm_unreachable("no ownership!"); break;
     case Qualifiers::OCL_ExplicitNone: S += "none"; break;
     case Qualifiers::OCL_Strong: S += "strong"; break;
     case Qualifiers::OCL_Weak: S += "weak"; break;
@@ -845,9 +845,9 @@
 void TypePrinter::printAttributed(const AttributedType *T,
                                   std::string &S) {
-  // Prefer the macro forms of the GC and lifetime qualifiers.
+  // Prefer the macro forms of the GC and ownership qualifiers.
   if (T->getAttrKind() == AttributedType::attr_objc_gc ||